@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-# Author: Roberto Alsina <roberto.alsina@canonical.com>
 #
-# Copyright 2011-2012 Canonical Ltd.
+# Copyright 2011-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -32,14 +31,9 @@
 import sys
 
 if sys.platform != 'win32':
-    try:
-        from twisted.internet import gireactor
-        gireactor.install()
-    except ImportError:
-        from twisted.internet import glib2reactor
-        glib2reactor.install()
+    from twisted.internet import gireactor
+    gireactor.install()
 
-# pylint: disable=F0401, E1101
 from twisted.internet import reactor
 from twisted.internet.defer import inlineCallbacks
 from ubuntuone.platform.credentials import CredentialsManagementTool
