@@ -1,6 +1,4 @@
-# Apport integration for Ubuntu One client
-#
-# Copyright 2009-2012 Canonical Ltd.
+# Copyright 2009-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -28,22 +26,23 @@
 # files in the program, then also delete it here.
 """Stub for Apport"""
 
-# pylint: disable-msg=F0401,C0103
-# shut up about apport. We know. We aren't going to backport it for pqm
+from __future__ import print_function, unicode_literals
+
 import apport
+import os
+
 from apport.hookutils import attach_file_if_exists
-import os.path
 from dirspec.basedir import xdg_cache_home, xdg_config_home
 
 # Paths where things we might want live
-u1_log_path = os.path.join(xdg_cache_home, "ubuntuone", "log")
-u1_user_config_path = os.path.join(xdg_config_home, "ubuntuone")
+u1_log_path = os.path.join(xdg_cache_home, b"ubuntuone", b"log")
+u1_user_config_path = os.path.join(xdg_config_home, b"ubuntuone")
 # things we may want to collect for the report
-u1_client_log = os.path.join(u1_log_path, "syncdaemon.log")
-u1_except_log = os.path.join(u1_log_path, "syncdaemon-exceptions.log")
-u1_invalidnames_log = os.path.join(u1_log_path, "syncdaemon-invalid-names.log")
-u1_sd_conf = os.path.join("etc", "xdg", "ubuntuone", "syncdaemon.conf")
-u1_usersd_conf = os.path.join(u1_user_config_path, "syncdaemon.conf")
+u1_client_log = os.path.join(u1_log_path, b"syncdaemon.log")
+u1_except_log = os.path.join(u1_log_path, b"syncdaemon-exceptions.log")
+u1_invalidnames_log = os.path.join(u1_log_path, b"syncdaemon-invalid-names.log")
+u1_sd_conf = os.path.join(b"etc", b"xdg", b"ubuntuone", b"syncdaemon.conf")
+u1_usersd_conf = os.path.join(u1_user_config_path, b"syncdaemon.conf")
 
 
 def add_info(report):
