@@ -500,7 +500,9 @@ daemon_ready_cb (SyncdaemonDaemon daemon, gpointer user_data)
 int
 main (int argc, gchar *argv[])
 {
-	g_type_init ();
+#ifndef GLIB_VERSION_2_36
+    g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	/* Initialize main object */
