@@ -35,6 +35,11 @@ import tempfile
 import thread
 
 from twisted.internet import defer
+
+import fsevents
+
+from contrib.testing.testcase import BaseTwistedTestCase
+
 from ubuntuone.devtools.handlers import MementoHandler
 from ubuntuone.platform.filesystem_notifications.monitor import (
     common,
@@ -87,6 +92,28 @@ class FakeFileEvent(object):
         self.name = name
 
 
+class FakeObserver(object):
+    """Fake fsevents.py Observer for tests that don't need real events."""
+
+    def __init__(self, latency=0, process_asap=True):
+        """Do nothing."""
+
+    def start(self):
+        """Do nothing."""
+
+    def stop(self):
+        """Do nothing."""
+
+    def join(self):
+        """Do nothing."""
+
+    def schedule(self, stream):
+        """Ignore"""
+
+    def unschedule(self, stream):
+        """Ignore"""
+
+
 class TestCaseHandler(ProcessEvent):
     """ProcessEvent used for test cases."""
 
@@ -490,6 +517,7 @@ class TestWatch(common_tests.TestWatch):
         """Test that the exclude filter works as expectd."""
         handler = TestCaseHandler(number_events=0)
         manager = WatchManager(handler)
+        self.addCleanup(manager.stop)
         # add a watch that will always exclude all actions
         manager.add_watch(self.basedir, self.mask,
             exclude_filter=lambda x: True)
@@ -596,32 +624,29 @@ class TestWatch(common_tests.TestWatch):
         self.assertTrue(path not in watch._subdirs)
 
 
-class TestWatchManager(common_tests.TestWatchManager):
-    """Test the watch manager."""
+class TestWatchManagerStopping(common_tests.TestWatchManagerStopping):
+    """Test stopping the watch manager."""
 
     @defer.inlineCallbacks
     def setUp(self):
         """Set each of the tests."""
-        yield super(TestWatchManager, self).setUp()
+        yield super(TestWatchManagerStopping, self).setUp()
         self.parent_path = '/Users/username/'
         self.path = self.parent_path + 'path'
         self.watch = Watch(1, self.path, None)
-        self.manager = WatchManager(None)
         self.manager._wdm = {1: self.watch}
         self.stream = None
         self.fake_events_processor = FakeEventsProcessor()
+        self.patch(self.manager.platform_manager.observer, "unschedule",
+                   lambda x: None)
 
     @defer.inlineCallbacks
     def test_stop(self):
         """Test that the different watches are stopped."""
-        self.patch(self.manager.manager.observer, "unschedule",
-            lambda x: None)
-        self.patch(self.manager.manager.observer, "unschedule", lambda x: None)
-        yield super(TestWatchManager, self).test_stop()
+        yield super(TestWatchManagerStopping, self).test_stop()
 
     def test_stop_multiple(self):
         """Watches should became watching=False and the observer stopped."""
-        self.patch(self.manager.manager.observer, "unschedule", lambda x: None)
         second_path = self.parent_path + "second_path"
         second_watch = Watch(2, second_path, None)
         second_watch._watching = True
@@ -630,8 +655,29 @@ class TestWatchManager(common_tests.TestWatchManager):
         self.assertFalse(second_watch.platform_watch.watching)
         self.assertEqual(second_watch._subdirs, set())
         # Give time to the thread to be finished.
-        self.manager.manager.observer.join()
-        self.assertFalse(self.manager.manager.observer.is_alive())
+        self.manager.platform_manager.observer.join()
+        self.assertFalse(self.manager.platform_manager.observer.is_alive())
+
+
+class TestWatchManager(common_tests.TestWatchManager):
+    """Test the watch manager."""
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        """Setup."""
+
+        # Note: patching Observer before super.setUp because it is
+        # used by the WatchManager we create there.
+        self.patch(fsevents, "Observer", FakeObserver)
+
+        yield super(TestWatchManager, self).setUp()
+
+        self.parent_path = '/Users/username/'
+        self.path = self.parent_path + 'path'
+        self.watch = Watch(1, self.path, None)
+        self.manager._wdm = {1: self.watch}
+        self.stream = None
+        self.fake_events_processor = FakeEventsProcessor()
 
     def test_get_present_watch(self):
         """Test that we can get a Watch using is wd."""
@@ -678,7 +724,8 @@ class TestWatchManager(common_tests.TestWatchManager):
 
     def test_rm_present_wd(self):
         """Test the removal of a present watch."""
-        self.patch(self.manager.manager.observer, "unschedule", lambda x: None)
+        self.patch(self.manager.platform_manager.observer,
+                   "unschedule", lambda x: None)
         super(TestWatchManager, self).test_rm_present_wd()
 
     def test_rm_child_path(self):
@@ -688,7 +735,7 @@ class TestWatchManager(common_tests.TestWatchManager):
         super(TestWatchManager, self).test_rm_child_path()
 
 
-class TestWatchManagerAddWatches(common_tests.TestWatchManagerAddWatches):
+class TestWatchManagerAddWatches(BaseTwistedTestCase):
     """Test the watch manager."""
     timeout = 5
 
@@ -697,7 +744,7 @@ class TestWatchManagerAddWatches(common_tests.TestWatchManagerAddWatches):
         self.patch(Watch, "start_watching", lambda self: None)
         self.patch(Watch, "started", lambda self: True)
         manager = WatchManager(None)
-        # no need to stop watching because start_watching is fake
+        self.addCleanup(manager.stop)
 
         path = '/Users/username/path'
         mask = 'fake bit mask'
@@ -1074,7 +1121,7 @@ class FilesystemMonitorTestCase(BaseFSMonitorTestCase):
         self.patch(Watch, "start_watching", lambda self: None)
         self.patch(Watch, "started", lambda self: True)
         manager = WatchManager(None)
-        # no need to stop watching because start_watching is fake
+        self.addCleanup(manager.stop)
 
         path = '/Users/username/path'
         mask = 'fake bit mask'
