@@ -78,6 +78,7 @@ from ubuntuone.platform.ipc.ipc_client import (
 )
 from ubuntuone.syncdaemon import interaction_interfaces
 
+from ubuntu_sso.networkstate.networkstates import ONLINE
 
 TEST_PORT = 40404
 TEST_DOMAIN_SOCKET = os.path.join(basedir.xdg_cache_home, 'ubuntuone', 'ipc')
@@ -351,6 +352,18 @@ class FakeRemoteObject(object):
         self.called.append(args)
 
 
+class FakeNetworkManagerState(object):
+    """Fake NetworkState."""
+
+    def __init__(self, result_cb=None):
+        """Just save callback."""
+        self.cb = result_cb
+
+    def find_online_state(self):
+        """Always say ONLINE."""
+        self.cb(ONLINE)
+
+
 class RemoteClientTestCase(TestCase):
     """Tests for the RemoteClient class."""
 
@@ -381,7 +394,8 @@ class IPCTestCase(FakeMainTestCase, TCPPbServerTestCase):
         self.patch(ipc, 'ActivationClient', FakeActivationClient)
         # patch the interaction interfaces to not choose the system one but
         # always the perspective broker one
-        self.patch(interaction_interfaces, 'ExternalInterface', ipc.IPCInterface)
+        self.patch(interaction_interfaces, 'ExternalInterface',
+                   ipc.IPCInterface)
 
         yield super(IPCTestCase, self).setUp()
 
@@ -399,6 +413,11 @@ class IPCTestCase(FakeMainTestCase, TCPPbServerTestCase):
 
         self.bus = None  # parity with linux code
 
+        # patch the networkmanagerstate to avoid spawning unnecessary
+        # threads when we instantiate the syncdaemonservice:
+        self.patch(interaction_interfaces, 'NetworkManagerState',
+                   FakeNetworkManagerState)
+
         self.service = self.service_class(main=self.main, send_events=True)
         self.service.oauth_credentials = ('foo', 'bar')
 
@@ -517,7 +536,7 @@ class IPCTestCase(FakeMainTestCase, TCPPbServerTestCase):
             setattr(remote_client, remote_cb_name, fake_remote_cb)
             self.addCleanup(delattr, remote_client, remote_cb_name)
 
-            remote_client_func = getattr(remote_client, 
+            remote_client_func = getattr(remote_client,
                                          remote_client_func_name)
 
             result = remote_client_func(*args)
