@@ -2,7 +2,7 @@
 #
 # Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,16 +15,32 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Linux specific tests for the platform module."""
+
 import os
 import uuid
 
 from twisted.internet import defer
 
-from contrib.testing.testcase import FakeMain, environ
+from contrib.testing.testcase import FakeMain
 from tests.syncdaemon.test_vm import MetadataTestCase, BaseVolumeManagerTests
 from ubuntuone.storageprotocol import request
 from ubuntuone.syncdaemon.volume_manager import (
+    ACCESS_LEVEL_RO,
+    ACCESS_LEVEL_RW,
     get_udf_path,
     LegacyShareFileShelf, _Share, Share, Shared, Root, UDF, _UDF,
     MetadataUpgrader, VMFileShelf,
@@ -37,12 +53,12 @@ class VolumesTests(BaseVolumeManagerTests):
     def test_get_udf_path(self):
         """Test for get_udf_path."""
         suggested_path = u"suggested_path"
-        with environ('HOME', self.home_dir):
-            udf_path = get_udf_path(u"~/" + suggested_path)
+        udf_path = get_udf_path(u"~/" + suggested_path)
         self.assertEquals(os.path.join(self.home_dir,
                                        suggested_path.encode('utf-8')),
                           udf_path)
 
+
 class MetadataOldLayoutTests(MetadataTestCase):
     """Tests for 'old' layouts and metadata upgrade"""
 
@@ -81,11 +97,11 @@ class MetadataOldLayoutTests(MetadataTestCase):
         old_shelf = LegacyShareFileShelf(self.share_md_dir)
         # add the root_uuid key
         root_share = _Share(path=self.root_dir)
-        root_share.access_level = 'Modify'
+        root_share.access_level = ACCESS_LEVEL_RW
         old_shelf[request.ROOT] = root_share
         for idx in range(1, 10):
             sid = str(uuid.uuid4())
-            old_shelf[sid] =  _Share(
+            old_shelf[sid] = _Share(
                 path=os.path.join(self.shares_dir, str(idx)), share_id=sid)
         # ShareFileShelf.keys returns a generator
         old_keys = [key for key in old_shelf.keys()]
@@ -149,7 +165,7 @@ class MetadataOldLayoutTests(MetadataTestCase):
         self.main = FakeMain(self.new_root_dir, self.new_shares_dir,
                              self.data_dir, self.partials_dir)
         new_keys = [new_key for new_key in self.main.vm.shares.keys()]
-        self.assertEquals(2, len(new_keys)) # the fake share plus root
+        self.assertEquals(2, len(new_keys))  # the fake share plus root
         for key in [request.ROOT, share.id]:
             self.assertIn(key, new_keys)
         self.check_version()
@@ -186,7 +202,7 @@ class MetadataOldLayoutTests(MetadataTestCase):
         expected = []
 
         for dirname, new_dirname in [(self.root_dir, self.new_root_dir),
-                                          (self.shares_dir, self.new_shares_dir)]:
+                                     (self.shares_dir, self.new_shares_dir)]:
             # a plain .conflict...
             # ...on a file
             open(dirname + '/1a.conflict', 'w').close()
@@ -345,7 +361,7 @@ class MetadataOldLayoutTests(MetadataTestCase):
         maybe_old_shelf = LegacyShareFileShelf(self.share_md_dir)
         # add the root_uuid key
         root_share = _Share(path=self.root_dir)
-        root_share.access_level = 'Modify'
+        root_share.access_level = ACCESS_LEVEL_RW
         maybe_old_shelf[request.ROOT] = root_share
         for idx in range(1, 10):
             share_id = str(uuid.uuid4())
@@ -457,9 +473,11 @@ class MetadataNewLayoutTests(MetadataTestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield super(MetadataNewLayoutTests, self).setUp()
+        # We need to define home_dir here to add 'home' to the path
+        # and avoid crashes between existing paths.
+        self.home_dir = os.path.join(self.tmpdir, 'home', 'ubuntuonehacker')
         self.share_md_dir = os.path.join(self.vm_data_dir, 'shares')
         self.shared_md_dir = os.path.join(self.vm_data_dir, 'shared')
-        self.home_dir = os.path.join(self.tmpdir, 'home', 'ubuntuonehacker')
         self.u1_dir = os.path.join(self.home_dir, os.path.split(self.u1_dir)[1])
         self.root_dir = self.u1_dir
         self.shares_dir = os.path.join(self.tmpdir, 'shares')
@@ -506,7 +524,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
         self.set_md_version('')
         shares = LegacyShareFileShelf(self.share_md_dir)
         root_share = _Share(path=self.root_dir)
-        root_share.access_level = 'Modify'
+        root_share.access_level = ACCESS_LEVEL_RW
         # set None to the share path
         root_share.path = None
         shares[request.ROOT] = root_share
@@ -548,7 +566,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
         # create some old shares and shared metadata
         legacy_shares = LegacyShareFileShelf(self.share_md_dir)
         root_share = _Share(path=self.root_dir, share_id=request.ROOT,
-                            access_level='Modify')
+                            access_level=ACCESS_LEVEL_RW)
         legacy_shares[request.ROOT] = root_share
         for idx, name in enumerate(['share'] * 10):
             sid = str(uuid.uuid4())
@@ -556,12 +574,12 @@ class MetadataNewLayoutTests(MetadataTestCase):
             share = _Share(path=os.path.join(self.shares_dir, share_name),
                            share_id=sid, name=share_name,
                            node_id=str(uuid.uuid4()),
-                           other_username='username'+str(idx),
+                           other_username='username' + str(idx),
                            other_visible_name='visible name ' + str(idx))
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shares[sid] = share
 
         # create shared shares
@@ -574,9 +592,9 @@ class MetadataNewLayoutTests(MetadataTestCase):
                            name=share_name, other_username='hola',
                            other_visible_name='hola')
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shared[sid] = share
 
         # keep a copy of the current shares and shared metadata to check
@@ -590,6 +608,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
         self.main = FakeMain(self.root_dir, self.shares_dir,
                              self.data_dir, self.partials_dir)
         vm = self.main.vm
+
         def compare_share(share, old_share):
             """Compare two shares, new and old"""
             self.assertEquals(share.volume_id, old_share.id)
@@ -625,7 +644,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
         # create some old shares and shared metadata
         legacy_shares = LegacyShareFileShelf(self.share_md_dir)
         root_share = _Share(path=self.root_dir, share_id=request.ROOT,
-                            access_level='Modify')
+                            access_level=ACCESS_LEVEL_RW)
         legacy_shares[request.ROOT] = root_share
         for idx, name in enumerate(['share'] * 10):
             sid = str(uuid.uuid4())
@@ -633,12 +652,12 @@ class MetadataNewLayoutTests(MetadataTestCase):
             share = _Share(path=os.path.join(self.shares_dir, share_name),
                            share_id=sid, name=share_name,
                            node_id=str(uuid.uuid4()),
-                           other_username='username'+str(idx),
+                           other_username='username' + str(idx),
                            other_visible_name='visible name ' + str(idx))
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shares[sid] = share
 
         # create shared shares
@@ -651,9 +670,9 @@ class MetadataNewLayoutTests(MetadataTestCase):
                            name=share_name, other_username='hola',
                            other_visible_name='hola')
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shared[sid] = share
 
         # create some udfs
@@ -682,6 +701,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
         self.main = FakeMain(self.root_dir, self.shares_dir,
                              self.data_dir, self.partials_dir)
         vm = self.main.vm
+
         def compare_share(share, old_share):
             """Compare two shares, new and old"""
             self.assertEquals(share.volume_id, old_share.id)
@@ -728,7 +748,8 @@ class MetadataNewLayoutTests(MetadataTestCase):
         # create some old shares and shared metadata
         legacy_shares = LegacyShareFileShelf(self.share_md_dir)
         root_share = _Share(path=self.root_dir, share_id=request.ROOT,
-                            access_level='Modify', node_id=str(uuid.uuid4()))
+                            access_level=ACCESS_LEVEL_RW, node_id=str(
+                                uuid.uuid4()))
         legacy_shares[request.ROOT] = root_share
         for idx, name in enumerate(['share'] * 3):
             sid = str(uuid.uuid4())
@@ -736,17 +757,17 @@ class MetadataNewLayoutTests(MetadataTestCase):
             share = _Share(path=os.path.join(self.shares_dir, share_name),
                            share_id=sid, name=share_name,
                            node_id=str(uuid.uuid4()),
-                           other_username='username'+str(idx),
+                           other_username='username' + str(idx),
                            other_visible_name='visible name ' + str(idx))
             if idx == 0:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
                 legacy_shares[sid] = share
             elif idx == 1:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
                 legacy_shares[sid] = share
             else:
                 # add a 'new' Share dict to the shelf
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
                 share = Share(path=share.path,
                                volume_id=share.id, name=share.name,
                                access_level=share.access_level,
@@ -765,14 +786,14 @@ class MetadataNewLayoutTests(MetadataTestCase):
                            name=share_name, other_username='hola',
                            other_visible_name='hola')
             if idx == 0:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
                 legacy_shares[sid] = share
             elif idx == 1:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
                 legacy_shares[sid] = share
             else:
                 # add a 'new' Shared dict to the shelf
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
                 share = Shared(path=share.path,
                                volume_id=share.id, name=share.name,
                                access_level=share.access_level,
@@ -792,6 +813,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
         self.main = FakeMain(self.root_dir, self.shares_dir,
                              self.data_dir, self.partials_dir)
         vm = self.main.vm
+
         def compare_share(share, old_share):
             """Compare two shares, new and old"""
             old_id = getattr(old_share, 'id', None)
@@ -835,7 +857,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
         # create some old shares and shared metadata
         legacy_shares = LegacyShareFileShelf(self.share_md_dir)
         root_share = _Share(path=self.root_dir, share_id=request.ROOT,
-                            access_level='Modify')
+                            access_level=ACCESS_LEVEL_RW)
         legacy_shares[request.ROOT] = root_share
         for idx, name in enumerate(['share'] * 10):
             sid = str(uuid.uuid4())
@@ -843,12 +865,12 @@ class MetadataNewLayoutTests(MetadataTestCase):
             share = _Share(path=os.path.join(self.shares_dir, share_name),
                            share_id=sid, name=share_name,
                            node_id=str(uuid.uuid4()),
-                           other_username='username'+str(idx),
+                           other_username='username' + str(idx),
                            other_visible_name='visible name ' + str(idx))
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shares[sid] = share
         # create shared shares
         legacy_shared = LegacyShareFileShelf(self.shared_md_dir)
@@ -860,9 +882,9 @@ class MetadataNewLayoutTests(MetadataTestCase):
                            name=share_name, other_username='hola',
                            other_visible_name='hola')
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shared[sid] = share
 
         # keep a copy of the current shares and shared metadata to check
@@ -874,6 +896,7 @@ class MetadataNewLayoutTests(MetadataTestCase):
             self.set_md_version('')
         # upgrade it!
         old_upgrade_share_to_volume = MetadataUpgrader._upgrade_share_to_volume
+
         def upgrade_share_to_volume(share, shared=False):
             raise ValueError('FAIL!')
         MetadataUpgrader._upgrade_share_to_volume = upgrade_share_to_volume
@@ -926,12 +949,12 @@ class MetadataNewLayoutTests(MetadataTestCase):
             share = Share(path=os.path.join(self.shares_dir, share_name),
                            volume_id=sid, name=share_name,
                            node_id=str(uuid.uuid4()),
-                           other_username='username'+str(idx),
+                           other_username='username' + str(idx),
                            other_visible_name='visible name ' + str(idx))
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shares[sid] = share
 
         # create shared shares
@@ -944,9 +967,9 @@ class MetadataNewLayoutTests(MetadataTestCase):
                            name=share_name, other_username='hola',
                            other_visible_name='hola')
             if idx % 2:
-                share.access_level = 'Modify'
+                share.access_level = ACCESS_LEVEL_RW
             else:
-                share.access_level = 'View'
+                share.access_level = ACCESS_LEVEL_RO
             legacy_shared[sid] = share
 
         # create some udfs
@@ -1003,4 +1026,3 @@ class BrokenOldMDVersionUpgradeTests(MetadataOldLayoutTests):
 class BrokenNewMDVersionUpgradeTests(MetadataNewLayoutTests):
     """MetadataNewLayoutTests with broken .version file."""
     md_version_None = True
-
