@@ -42,11 +42,11 @@ from ubuntuone.devtools.handlers import MementoHandler
 from ubuntuone.devtools.testcases import skipTest
 from ubuntuone.status import aggregator
 from ubuntuone.status.notification import AbstractNotification
-from ubuntuone.status.messaging import AbstractMessaging
 from ubuntuone.syncdaemon import (
     status_listener,
     RECENT_TRANSFERS,
     UPLOADING,
+    DOWNLOADING
 )
 from ubuntuone.syncdaemon.volume_manager import Share, UDF, Root
 
@@ -193,37 +193,6 @@ def FakeNotificationSingleton():
     return get_instance
 
 
-class FakeMessaging(AbstractMessaging):
-    """A fake messaging class."""
-
-    def __init__(self):  # pylint: disable=W0231
-        self.messages_shown = {}
-        self.messages_updated = {}
-        self.callbacks = []
-
-    # pylint: disable=R0913
-    def show_message(self, sender, callback=None, message_time=None,
-                     message_count=None, icon=None):
-        """Show a message to the user."""
-        if message_count and sender in self.messages_shown:
-            self.update_count(sender, message_count)
-        self.messages_shown[sender] = (
-            callback, message_time, message_count, icon)
-    # pylint: enable=R0913
-
-    def update_count(self, sender, add_count):
-        """Update the count for an existing indicator."""
-        self.messages_updated[sender] = (sender, add_count)
-
-    def _callback(self, indicator, message_time=None):
-        """Fake callback."""
-        self.callbacks.append((indicator, message_time))
-
-    def create_callback(self):
-        """Create the callback."""
-        return self._callback
-
-
 class FakeStatusAggregator(object):
     """A fake status aggregator."""
 
@@ -240,7 +209,7 @@ class FakeStatusAggregator(object):
 
     def build_discovery_message(self):
         """Build the file discovery message."""
-        return "a lot of files found (%d).""" % self.discovered
+        return "a lot of files found (%d)." % self.discovered
 
     def get_progress_message(self):
         """Return the progress message."""
@@ -250,11 +219,11 @@ class FakeStatusAggregator(object):
     def build_progress_message(self):
         """Build the progress message."""
         params = (self.discovered, self.completed)
-        return "a lot of files transferring (%d/%d).""" % params
+        return "a lot of files transferring (%d/%d)." % params
 
     def get_final_status_message(self):
         """Return the final status message."""
-        return "a lot of files completed."""
+        return "a lot of files completed."
 
     def get_notification(self):
         """Create a new toggleable notification object."""
@@ -713,9 +682,22 @@ class FakeCommand(object):
         self.node_id = path
         self.deflated_size = 10000
         self.size = 0
+
+
+class FakeUploadCommand(FakeCommand):
+    """A fake upload."""
+    def __init__(self, path=''):
+        super(FakeUploadCommand, self).__init__(path)
         self.n_bytes_written = 0
 
 
+class FakeDownloadCommand(FakeCommand):
+    """A fake upload."""
+    def __init__(self, path=''):
+        super(FakeDownloadCommand, self).__init__(path)
+        self.n_bytes_read = 0
+
+
 class FakeVolumeManager(object):
     """A fake vm."""
 
@@ -760,6 +742,7 @@ class FakeAggregator(object):
         """A download just finished."""
         if command in self.files_downloading:
             self.files_downloading.remove(command)
+        self.recent_transfers.append(command.path)
         self.queued_commands.discard(command)
 
     def upload_started(self, command):
@@ -798,7 +781,6 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
         self.patch(aggregator, "StatusAggregator", FakeAggregator)
         self.patch(aggregator, "ToggleableNotification",
                    FakeNotificationSingleton())
-        self.patch(aggregator, "Messaging", FakeMessaging)
         self.fakefsm = None
         self.fakevm = FakeVolumeManager()
         self.status_frontend = aggregator.StatusFrontend()
@@ -808,14 +790,17 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
 
     def test_recent_transfers(self):
         """Check that it generates a tuple with the recent transfers."""
-        self.patch(status_listener.action_queue, "Upload", FakeCommand)
-        fake_command = FakeCommand('path1')
+        self.patch(status_listener.action_queue, "Upload", FakeUploadCommand)
+        self.patch(status_listener.action_queue, "Download",
+                   FakeDownloadCommand)
+
+        fake_command = FakeUploadCommand('path1')
         self.listener.handle_SYS_QUEUE_ADDED(fake_command)
         self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
-        fake_command = FakeCommand('path2')
+        fake_command = FakeUploadCommand('path2')
         self.listener.handle_SYS_QUEUE_ADDED(fake_command)
         self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
-        fake_command = FakeCommand('path3')
+        fake_command = FakeDownloadCommand('path3')
         self.listener.handle_SYS_QUEUE_ADDED(fake_command)
         self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
         transfers = self.status_frontend.recent_transfers()
@@ -824,24 +809,28 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
 
         menu_data = self.listener.menu_data()
         self.assertEqual(menu_data,
-            {UPLOADING: [], RECENT_TRANSFERS: expected})
+            {UPLOADING: [],
+             DOWNLOADING: [],
+             RECENT_TRANSFERS: expected})
 
-    def test_file_uploading(self):
+    def test_files_uploading(self):
         """Check that it returns a list with the path, size, and progress."""
-        fc = FakeCommand(path='testfile.txt')
-        fc.size = 200
+        fc = FakeUploadCommand(path='testfile.txt')
+        fc.deflated_size = 200
         self.status_frontend.upload_started(fc)
         uploading = self.status_frontend.files_uploading()
         expected = [('testfile.txt', 200, 0)]
         self.assertEqual(uploading, expected)
         menu_data = self.listener.menu_data()
         self.assertEqual(menu_data,
-            {UPLOADING: expected, RECENT_TRANSFERS: []})
+            {UPLOADING: expected,
+             DOWNLOADING: [],
+             RECENT_TRANSFERS: []})
 
-        fc.size = 1000
+        fc.deflated_size = 1000
         fc.n_bytes_written = 200
-        fc2 = FakeCommand(path='testfile2.txt')
-        fc2.size = 2000
+        fc2 = FakeUploadCommand(path='testfile2.txt')
+        fc2.deflated_size = 2000
         fc2.n_bytes_written = 450
         self.status_frontend.upload_started(fc2)
         uploading = self.status_frontend.files_uploading()
@@ -850,25 +839,100 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
 
         menu_data = self.listener.menu_data()
         self.assertEqual(menu_data,
-            {UPLOADING: expected, RECENT_TRANSFERS: []})
+            {UPLOADING: expected,
+             DOWNLOADING: [],
+             RECENT_TRANSFERS: []})
+
+    def test_files_downloading(self):
+        """Check that it returns a list with the path, size, and progress."""
+        fc = FakeDownloadCommand(path='testfile.txt')
+        fc.deflated_size = 200
+        self.status_frontend.download_started(fc)
+        downloading = self.status_frontend.files_downloading()
+        expected = [('testfile.txt', 200, 0)]
+        self.assertEqual(downloading, expected)
+        menu_data = self.listener.menu_data()
+        self.assertEqual(menu_data,
+            {DOWNLOADING: expected,
+             UPLOADING: [],
+             RECENT_TRANSFERS: []})
+
+        fc.deflated_size = 1000
+        fc.n_bytes_read = 200
+        fc2 = FakeDownloadCommand(path='testfile2.txt')
+        fc2.deflated_size = 2000
+        fc2.n_bytes_read = 450
+        self.status_frontend.download_started(fc2)
+        downloading = self.status_frontend.files_downloading()
+        expected = [('testfile.txt', 1000, 200), ('testfile2.txt', 2000, 450)]
+        self.assertEqual(downloading, expected)
+
+        menu_data = self.listener.menu_data()
+        self.assertEqual(menu_data,
+            {DOWNLOADING: expected,
+             UPLOADING: [],
+             RECENT_TRANSFERS: []})
+
+    def test_files_uploading_empty(self):
+        """Check that empty files are ignored."""
+        fc = FakeUploadCommand(path='testfile.txt')
+        fc.deflated_size = None
+        self.status_frontend.upload_started(fc)
+
+        fc2 = FakeUploadCommand(path='testfile2.txt')
+        fc2.deflated_size = 0
+        fc2.n_bytes_written = 450
+        self.status_frontend.upload_started(fc2)
+        uploading = self.status_frontend.files_uploading()
+        self.assertEqual(uploading, [])
+
+    def test_files_downloading_empty(self):
+        """Check that empty files are ignored."""
+        fc = FakeDownloadCommand(path='testfile.txt')
+        fc.deflated_size = None
+        self.status_frontend.download_started(fc)
+
+        fc2 = FakeDownloadCommand(path='testfile2.txt')
+        fc2.deflated_size = 0
+        fc2.n_bytes_written = 450
+        self.status_frontend.download_started(fc2)
+        downloading = self.status_frontend.files_downloading()
+        self.assertEqual(downloading, [])
 
     def test_menu_data_full_response(self):
-        """Check that listener.menu_data returns both uploading and recent."""
-        self.patch(status_listener.action_queue, "Upload", FakeCommand)
-        fake_command = FakeCommand('path1')
+        """listener.menu_data returns uploading, downloading, and recent."""
+        self.patch(status_listener.action_queue, "Upload", FakeUploadCommand)
+        fake_command = FakeUploadCommand('path1')
         self.listener.handle_SYS_QUEUE_ADDED(fake_command)
         self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
-        fc = FakeCommand(path='testfile.txt')
-        fc.size = 1000
+
+        self.patch(status_listener.action_queue, "Download",
+                   FakeDownloadCommand)
+        fake_command = FakeDownloadCommand('path2')
+        self.listener.handle_SYS_QUEUE_ADDED(fake_command)
+        self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
+
+        fc = FakeUploadCommand(path='testfile.txt')
+        fc.deflated_size = 1000
         fc.n_bytes_written = 200
         self.status_frontend.upload_started(fc)
+
+        fc = FakeDownloadCommand(path='download.pdf')
+        fc.deflated_size = 10
+        fc.n_bytes_read = 1
+        self.status_frontend.download_started(fc)
+
         uploading = self.status_frontend.files_uploading()
+        downloading = self.status_frontend.files_downloading()
         transfers = self.status_frontend.recent_transfers()
         expected = {UPLOADING: [('testfile.txt', 1000, 200)],
-            RECENT_TRANSFERS: ['path1']}
+                    DOWNLOADING: [('download.pdf', 10, 1)],
+                    RECENT_TRANSFERS: ['path1', 'path2']}
 
-        self.assertEqual(
-            {UPLOADING: uploading, RECENT_TRANSFERS: transfers}, expected)
+        self.assertEqual({UPLOADING: uploading,
+                          DOWNLOADING: downloading,
+                          RECENT_TRANSFERS: transfers},
+                         expected)
 
     def test_file_published(self):
         """A file published event is processed."""
@@ -990,11 +1054,6 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
         self.listener.handle_VM_SHARE_CREATED(SHARE_ID)
         self.assertEqual(
             1, len(self.status_frontend.notification.notifications_shown))
-        msg = self.status_frontend.messaging.messages_shown[FAKE_SENDER]
-        # msg did not receive a time argument
-        self.assertEqual(None, msg[1])
-        # msg did not receive a count argument
-        self.assertEqual(None, msg[2])
 
     def test_already_subscribed_new_udf_available(self):
         """A new udf that was already subscribed."""
@@ -1003,10 +1062,6 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
         self.listener.handle_VM_UDF_CREATED(udf)
         self.assertEqual(
             0, len(self.status_frontend.notification.notifications_shown))
-        self.assertEqual(
-            0, len(self.status_frontend.messaging.messages_shown))
-        self.assertEqual(
-            0, len(self.status_frontend.messaging.messages_updated))
 
     def test_new_udf_available(self):
         """A new udf is available for subscription."""
@@ -1014,11 +1069,6 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
         self.listener.handle_VM_UDF_CREATED(udf)
         self.assertEqual(
             1, len(self.status_frontend.notification.notifications_shown))
-        self.assertEqual(
-            0, len(self.status_frontend.messaging.messages_shown))
-        self.assertEqual(
-            0, len(self.status_frontend.messaging.messages_updated))
-        self.assertEqual(0, len(self.status_frontend.messaging.callbacks))
 
     def test_two_new_udfs_available(self):
         """A new udf is available for subscription."""
@@ -1028,10 +1078,6 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
         self.listener.handle_VM_UDF_CREATED(udf2)
         self.assertEqual(
             2, len(self.status_frontend.notification.notifications_shown))
-        self.assertEqual(
-            0, len(self.status_frontend.messaging.messages_shown))
-        self.assertEqual(
-            0, len(self.status_frontend.messaging.messages_updated))
 
     def test_server_connection_lost(self):
         """The client connected to the server."""
@@ -1330,6 +1376,36 @@ class StatusAggregatorTestCase(TestCase):
             self.aggregator.register_progress_listener, [])
         self.assertEqual(len(self.aggregator.progress_listeners), 0)
 
+    def test_register_connection_listener(self):
+        """Check that register listener handles properly additions."""
+
+        def fake_callback():
+            """Do nothing."""
+
+        self.aggregator.register_connection_listener(fake_callback)
+        self.assertEqual(len(self.aggregator.connection_listeners), 1)
+
+    def test_register_connection_listener_fail(self):
+        """Check that register listener fails with not Callable objects."""
+        self.assertRaises(TypeError,
+            self.aggregator.register_connection_listener, [])
+        self.assertEqual(len(self.aggregator.connection_listeners), 0)
+
+    def test_connection_notifications(self):
+        """Check that the connection lister is notified."""
+        data = {}
+
+        def fake_callback(status):
+            """Register status."""
+            data['status'] = status
+
+        self.aggregator.register_connection_listener(fake_callback)
+        self.assertEqual(data, {})
+        self.aggregator.connection_lost()
+        self.assertFalse(data['status'])
+        self.aggregator.connection_made()
+        self.assertTrue(data['status'])
+
     def assertMiscCommandQueued(self, fc):
         """Assert that some command was queued."""
         self.assertEqual(len(self.aggregator.to_do), 1)
@@ -1372,6 +1448,7 @@ class StatusAggregatorTestCase(TestCase):
         self.assertEqual(
             {(fc.share_id, fc.node_id): (fc.deflated_size)},
             self.aggregator.progress)
+        self.assertEqual(len(self.aggregator.recent_transfers), 1)
 
     def test_file_upload_started(self):
         """Test that a file has started upload."""
@@ -1400,12 +1477,42 @@ class StatusAggregatorTestCase(TestCase):
 
     def test_max_recent_files(self):
         """Check that the queue doesn't exceed the 5 items."""
-        for i in range(15):
-            fc = FakeCommand()
+        for i in range(10):
+            fc = FakeUploadCommand(str(i))
             self.status_frontend.upload_started(fc)
             self.status_frontend.upload_finished(fc)
+        for i in range(10):
+            fc = FakeDownloadCommand(str(i))
+            self.status_frontend.download_started(fc)
+            self.status_frontend.download_finished(fc)
         self.assertEqual(len(self.aggregator.recent_transfers), 5)
 
+    def test_recent_transfers_is_unique(self):
+        """Check that a given path is not repeated in recent transfers."""
+        fc = FakeDownloadCommand('hi')
+        self.status_frontend.download_started(fc)
+        self.status_frontend.download_finished(fc)
+        fc = FakeDownloadCommand('hi')
+        self.status_frontend.download_started(fc)
+        self.status_frontend.download_finished(fc)
+        self.assertEqual(len(self.aggregator.recent_transfers), 1)
+
+    def test_recent_transfers_reorders(self):
+        """Check that if a transfer is repeated we put it back at the end."""
+        fc = FakeDownloadCommand('hi')
+        self.status_frontend.download_started(fc)
+        self.status_frontend.download_finished(fc)
+        fc = FakeDownloadCommand('howdy')
+        self.status_frontend.download_started(fc)
+        self.status_frontend.download_finished(fc)
+        fc = FakeUploadCommand('hi')
+        self.status_frontend.upload_started(fc)
+        self.status_frontend.upload_finished(fc)
+
+        self.assertEqual(len(self.aggregator.recent_transfers), 2)
+        self.assertEqual(['howdy', 'hi'],
+                         list(self.aggregator.recent_transfers))
+
     def test_progress_made(self):
         """Progress on up and downloads is tracked."""
         share_id = 'fake_share'
