@@ -42,6 +42,7 @@ from StringIO import StringIO
 from twisted.trial.unittest import TestCase as TwistedTestCase
 from twisted.internet import defer, reactor
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.devtools.testcases import skipTest
 
 from contrib.testing.testcase import BaseTwistedTestCase
 from ubuntuone.platform import open_file, stat_path
@@ -583,6 +584,7 @@ class HashQueueTests(BaseTwistedTestCase):
         self.assertEqual(kwargs['mdid'], "foo")
         self.assertTrue(call_later_called)
 
+    @skipTest('Causing intermittent failures. LP: #935568')
     def test_being_hashed(self):
         """Tell if something is being hashed."""
         tfile1 = os.path.join(self.test_dir, "tfile1")
