@@ -1531,7 +1531,7 @@ class BadStateTests(TwistedBase):
         mdobj = self.fsm.get_by_mdid(mdid)
         self.assertEqual(self.aq.uploaded[0][:7],
                          (mdobj.share_id, mdobj.node_id, mdobj.server_hash,
-                          mdobj.local_hash, mdobj.crc32, mdobj.size, path))
+                          mdobj.local_hash, mdobj.crc32, mdobj.size, mdid))
         self.assertEqual(self.aq.uploaded[1], {'upload_id':None})
         self.assertTrue(self.handler.check_debug("resuming upload",
                                                  "interrupted"))
@@ -1580,7 +1580,7 @@ class BadStateTests(TwistedBase):
         mdobj = self.fsm.get_by_mdid(mdid)
         self.assertEqual(self.aq.uploaded[0][:7],
                          (mdobj.share_id, mdobj.node_id, mdobj.server_hash,
-                          mdobj.local_hash, mdobj.crc32, mdobj.size, path))
+                          mdobj.local_hash, mdobj.crc32, mdobj.size, mdid))
         self.assertEqual(self.aq.uploaded[1], {'upload_id':'hola'})
         self.assertTrue(self.handler.check_debug("resuming upload",
                                                  "interrupted"))
@@ -1608,7 +1608,7 @@ class BadStateTests(TwistedBase):
         mdobj = self.fsm.get_by_mdid(mdid)
         self.assertEqual(self.aq.downloaded[:4],
                          (mdobj.share_id, mdobj.node_id,
-                          mdobj.server_hash, path))
+                          mdobj.server_hash, mdid))
         self.assertTrue(self.handler.check_debug("comp yield", "SERVER"))
 
     @defer.inlineCallbacks
@@ -1632,7 +1632,7 @@ class BadStateTests(TwistedBase):
         mdobj = self.fsm.get_by_mdid(mdid)
         self.assertEqual(self.aq.downloaded[:4],
                          (mdobj.share_id, mdobj.node_id,
-                          mdobj.server_hash, path))
+                          mdobj.server_hash, mdid))
         self.assertTrue(self.handler.check_debug("comp yield", "SERVER"))
 
     @defer.inlineCallbacks
@@ -1958,7 +1958,7 @@ class BadStateTests(TwistedBase):
         mdobj = self.fsm.get_by_mdid(mdid)
         self.assertEqual(self.aq.downloaded[:4],
                          (mdobj.share_id, mdobj.node_id,
-                          mdobj.server_hash, path))
+                          mdobj.server_hash, mdid))
         self.assertTrue(self.handler.check_debug("comp yield", "SERVER"))
 
     @defer.inlineCallbacks
