@@ -83,8 +83,6 @@ class MainTests(BaseTwistedTestCase):
         self.partials_dir = self.mktemp('partials_dir')
 
         self.patch(main_mod, 'SyncdaemonService', FakedExternalInterface)
-        # no event logger by default
-        self.patch(main_mod.event_logging, "get_listener", lambda *a: None)
         # no status listener by default
         self.patch(main_mod.status_listener, "get_listener", lambda *a: None)
 
@@ -257,18 +255,6 @@ class MainTests(BaseTwistedTestCase):
                 s.add(x)
         return s
 
-    def test_event_logger_starts_if_available(self):
-        """The event logger is started if available."""
-        self.patch(main_mod.event_logging,
-                   "get_listener", lambda *a: FakeListener())
-        main = self.build_main()
-        self.assertIn(main.eventlog_listener, self._get_listeners(main))
-
-    def test_event_logger_not_started_if_not_available(self):
-        """The event logger is not started if it's not available."""
-        main = self.build_main()
-        self.assertNotIn(main.eventlog_listener, self._get_listeners(main))
-
     def test_status_listener_is_installed(self):
         """The status listener is installed if needed."""
         self.patch(main_mod.status_listener,
