@@ -54,12 +54,6 @@ class GetListenerTestCase(BaseTwistedTestCase):
         self.assertEqual(listener.vm, vm)
         self.assertNotEqual(listener.status_frontend, None)
 
-    def test_zeitgeist_not_installed_returns_none(self):
-        """get_listener returns None if status reporting is disabled."""
-        self.patch(status_listener, "should_start_listener", lambda: False)
-        listener = status_listener.get_listener(None, None)
-        self.assertEqual(listener, None)
-
 
 def listen_for(event_q, event, callback, count=1, collect=False):
     """Setup a EQ listener for the specified event."""
