@@ -411,6 +411,12 @@ class FileSystem(DBusExposedObject):
         """Return a list of dirty nodes."""
         return self.service.file_system.get_dirty_nodes()
 
+    @dbus.service.method(DBUS_IFACE_FS_NAME,
+                         in_signature='s', out_signature='as')
+    def search_files(self, pattern):
+        """Return the files (as a list) that contain pattern in the path."""
+        return self.service.file_system.search_files(pattern)
+
 
 class Shares(DBusExposedObject):
     """An interface to interact with shares."""
