@@ -590,6 +590,12 @@ def path_exists(path):
     return os.path.exists(path) or native_is_link(path)
 
 
+@windowspath()
+def is_dir(path):
+    """Return if the path is an existing directory."""
+    return os.path.isdir(path)
+
+
 @windowspath()
 def make_dir(path, recursive=False):
     """Make a dir, optionally creating all the middle ones."""
