@@ -31,11 +31,11 @@
 
 class UbuntuOneSyncMenu(object):
     """Integrate U1 with the Ubuntu Sync Menu."""
-    def __init__(self, status, syncdaemon_service):
+    def __init__(self, *args, **kwargs):
         """Match #args of linux syncmenu and do nothing."""
 
-    def update_transfers(self):
+    def update_transfers(self, *args, **kwargs):
         """Do nothing."""
 
-    def sync_status_changed(self, status):
+    def sync_status_changed(self, *args, **kwargs):
         """Do nothing."""
