@@ -47,6 +47,9 @@ except:
 
 from ubuntuone.clientdefs import GETTEXT_PACKAGE
 from ubuntuone import status
+from ubuntuone.platform.sync_menu.common import (
+    UbuntuOneSyncMenu as DummySyncMenu,
+    )
 
 
 logger = logging.getLogger("ubuntuone.platform.SyncMenu")
@@ -277,21 +280,7 @@ class TransfersMenu(Dbusmenu.Menuitem if use_syncmenu else object):
                     items_added += 1
 
 
-class DummySyncMenu(object):
-    """Dummy SyncMenu"""
-
-    def __init__(self, *args, **kwargs):
-        """Initialize menu."""
-
-    def update_transfers(self):
-        """Do nothing."""
-
-    def sync_status_changed(self):
-        """Do nothing."""
-
-
 if use_syncmenu:
     UbuntuOneSyncMenu = UbuntuOneSyncMenuLinux
 else:
     UbuntuOneSyncMenu = DummySyncMenu
-    TransfersMenu = None
