@@ -2,7 +2,7 @@
 #
 # Author: Lucio Torre <lucio.torre@canonical.com>
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,10 +15,24 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """
 Will read the output produced by fsm_parser.parse or a .py serialization of
 it and create and validate a state machine.
 """
+
 import itertools
 
 from ubuntuone.syncdaemon import logger
@@ -27,6 +41,7 @@ try:
     product = itertools.product
 except AttributeError:
     # taken from python docs for 2.6
+
     def product(*args, **kwds):
         "cartesian product"
         # product('ABCD', 'xy') --> Ax Ay Bx By Cx Cy Dx Dy
@@ -34,7 +49,7 @@ except AttributeError:
         pools = map(tuple, args) * kwds.get('repeat', 1)
         result = [[]]
         for pool in pools:
-            result = [x+[y] for x in result for y in pool]
+            result = [x + [y] for x in result for y in pool]
         for prod in result:
             yield tuple(prod)
 
@@ -43,9 +58,11 @@ def hash_dict(d):
     "return a hashable representation of the dict"
     return tuple(sorted(d.items()))
 
+
 class ValidationFailed(Exception):
     """signals that the specification is not correct"""
 
+
 class ValidationError(object):
     """Contains validation errors"""
 
@@ -57,6 +74,7 @@ class ValidationError(object):
         "__str__"
         return "Validation Error: %s" % self.description
 
+
 def build_combinations_from_varlist(varlist):
     """ create all posible variable values combinations
 
@@ -64,14 +82,15 @@ def build_combinations_from_varlist(varlist):
     returns [{varname:value}, {varname:value2}, ...]
     """
     items = varlist.items()
-    keys = [ x[0] for x in items ]
+    keys = [x[0] for x in items]
     # pylint: disable-msg=W0631
-    values = [ x[1] for x in items ]
+    values = [x[1] for x in items]
 
     possible_states = [dict(zip(keys, state))
-                       for state in product(*values) ]
+                       for state in product(*values)]
     return possible_states
 
+
 def expand_var_list(varlist, values):
     """ exapand a state description
 
@@ -91,6 +110,7 @@ def expand_var_list(varlist, values):
             myvalues[name] = [myvalues[name]]
     return build_combinations_from_varlist(myvalues)
 
+
 class StateMachineRunner(object):
     """Reads a StateMachine descriptions and executes transitions."""
 
@@ -106,7 +126,7 @@ class StateMachineRunner(object):
         """Do the transition for this event.
         Returns the function called for the action"""
         # get the state
-        self.log.debug("EVENT: %s:%s with ARGS:%s"%(
+        self.log.debug("EVENT: %s:%s with ARGS:%s" % (
             event_name, parameters, args))
         try:
             enter_state = self.get_state()
@@ -216,7 +236,7 @@ class StateMachine(object):
     def validate(self):
         """Raises an exception if the file had errors."""
         if self.errors:
-            raise ValidationFailed("There are %s validation errors"%
+            raise ValidationFailed("There are %s validation errors" %
                                    len(self.errors))
         return True
 
@@ -231,19 +251,17 @@ class StateMachine(object):
                     value = state[kind][name]
                 except KeyError:
                     self.errors.append(ValidationError(
-                        "variable name '%s' not found in section %s"%(
+                        "variable name '%s' not found in section %s" % (
                            name, kind)))
                 else:
                     if str(value).strip() == "=" and kind != "STATE_OUT":
                         self.errors.append(ValidationError(
-                            "Cant have '=' in STATE or PARAMETERS section"
-                        ))
+                            "Cant have '=' in STATE or PARAMETERS section"))
                     if not str(value).strip() in ("*", "="):
                         if not str(value).strip()[0] == "!":
                             vals.add(value)
         return vals
 
-
     def build(self):
         """Do all the parsing and validating."""
         # build state variable posible values
@@ -272,9 +290,8 @@ class StateMachine(object):
                     possible_states.remove(es)
                 except ValueError:
                     self.errors.append(
-                        ValidationError("State %s already removed from invalid"%
-                                        es)
-                    )
+                        ValidationError(
+                            "State %s already removed from invalid" % es))
 
         for stateval in possible_states:
             self.states[hash_dict(stateval)] = State(stateval)
@@ -300,11 +317,10 @@ class StateMachine(object):
                     # invalid, because this is an error
                     self.errors.append(
                         ValidationError("Transitiont on %s with %s from '%s'"
-                                          "cant find source state."%(
+                                          "cant find source state." % (
                                             transition.event,
                                             transition.parameters,
-                                            transition.source
-                                            )))
+                                            transition.source)))
                     continue
                 s = {}
                 s.update(transition.source)
@@ -314,7 +330,7 @@ class StateMachine(object):
                 except ValueError:
                     self.errors.append(ValidationError(
                         "For event %s, the following transition was "
-                                          "already covered: %s"%(
+                                          "already covered: %s" % (
                                             event, transition)))
                 else:
                     state.add_transition(transition)
@@ -322,13 +338,14 @@ class StateMachine(object):
                 for s in tracker.pending:
                     self.errors.append(ValidationError(
                         "The following state x parameters where "
-                                      "not covered for '%s': %s"%(
+                                      "not covered for '%s': %s" % (
                                         event, s)))
 
     def get_state(self, vars_dict):
         """Get a state instance from a dict with {varname:value}"""
         return self.states[hash_dict(vars_dict)]
 
+
 class Tracker(object):
     """Tracks a list of state_x_params combinations.
 
@@ -346,6 +363,7 @@ class Tracker(object):
         """Check for pending cases."""
         return bool(self.pending)
 
+
 class Event(object):
     """Represents events that may happen.
 
@@ -454,7 +472,6 @@ class Event(object):
                 if not str(new_line["ACTION"]).strip() == "NA":
                     self.draw_transitions.append(Transition(name, new_line))
 
-
     def __str__(self):
         """__str___"""
         return "<Event: %s>" % self.name
