@@ -1,8 +1,6 @@
 # ubuntuone.syncdaemon.volume_manager - manages volumes
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +13,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """ The all mighty Volume Manager """
+
 from __future__ import with_statement
 
 import itertools
@@ -30,6 +42,7 @@ import stat
 from itertools import ifilter
 
 from twisted.internet import defer
+from ubuntuone.platform import expand_user
 from ubuntuone.storageprotocol import request
 from ubuntuone.storageprotocol.volumes import (
     ShareVolume,
@@ -54,6 +67,7 @@ from ubuntuone.platform import (
     listdir,
     make_dir,
     normpath,
+    open_file,
     path_exists,
     read_link,
     recursive_move,
@@ -71,12 +85,15 @@ SHARE_ROW_TYPE = 3
 SHARED_ROW_TYPE = 4
 UDF_ROW_TYPE = 5
 
+ACCESS_LEVEL_RO = 'View'
+ACCESS_LEVEL_RW = 'Modify'
+
 
 class _Share(object):
     """Represents a share or mount point"""
 
     def __init__(self, share_id=request.ROOT, node_id=None, path=None,
-                 name=None, access_level='View', accepted=False,
+                 name=None, access_level=ACCESS_LEVEL_RO, accepted=False,
                  other_username=None, other_visible_name=None):
         """ Creates the instance.
 
@@ -152,6 +169,7 @@ class Volume(object):
                                                               self.node_id,
                                                               self.generation)
 
+
 class Share(Volume):
     """A volume representing a Share."""
 
@@ -159,8 +177,8 @@ class Share(Volume):
 
     def __init__(self, volume_id=None, node_id=None, path=None, name=None,
                  other_username=None, other_visible_name=None, accepted=False,
-                 access_level='View', free_bytes=None, generation=None,
-                 subscribed=False):
+                 access_level=ACCESS_LEVEL_RO, free_bytes=None,
+                 generation=None, subscribed=False):
         """Create the share."""
         super(Share, self).__init__(volume_id, node_id, generation, subscribed)
         self.__dict__['type'] = 'Share'
@@ -224,10 +242,8 @@ class Share(Volume):
         return share
 
     def can_write(self):
-        """ check the access_level of this share,
-        returns True if it's 'Modify'.
-        """
-        return self.access_level == 'Modify'
+        """Return True if this share can be modified."""
+        return self.access_level == ACCESS_LEVEL_RW
 
     @property
     def active(self):
@@ -256,6 +272,7 @@ class Share(Volume):
                       self.access_level, self.other_username,
                       self.other_visible_name, self.name, self.path)
 
+
 class Shared(Share):
 
     def __init__(self, *args, **kwargs):
@@ -297,10 +314,12 @@ class Root(Volume):
     def from_volume(cls, volume):
         """Create a Root instance from a RootVolume."""
         # TODO: include the generation and the volume_id(?)
-        return cls(node_id=str(volume.node_id), free_bytes=volume.free_bytes, generation=volume.generation)
+        return cls(node_id=str(volume.node_id),
+            free_bytes=volume.free_bytes, generation=volume.generation)
 
     def __repr__(self):
-        return "<Root node_id %r, generation %r>" % (self.node_id, self.generation)
+        return "<Root node_id %r, generation %r>" % (
+            self.node_id, self.generation)
 
 
 class UDF(Volume):
@@ -327,7 +346,7 @@ class UDF(Volume):
         Return a list of paths that are 'syncdaemon' valid.
 
         """
-        user_home = os.path.expanduser('~')
+        user_home = expand_user('~')
         path_list = get_path_list(self.path)
         common_prefix = os.path.commonprefix([self.path, user_home])
         common_list = get_path_list(common_prefix)
@@ -502,7 +521,7 @@ class VolumeManager(object):
         """
         self.log.debug('handle_SV_VOLUME_NEW_GENERATION(%r, %r)',
                        volume_id, generation)
-        volume_id = str(volume_id) # be safe and use a str
+        volume_id = str(volume_id)  # be safe and use a str
         try:
             volume = self.get_volume(volume_id)
         except VolumeDoesNotExist:
@@ -545,12 +564,15 @@ class VolumeManager(object):
         """Do the 'server rescan'"""
         d = self.m.action_q.query_volumes()
         d.addCallback(self._volumes_rescan_cb)
+
         def cleanup(result):
             shares, udfs = result
             self._cleanup_volumes(shares=shares, udfs=udfs)
         d.addCallbacks(cleanup)
+
         def done(_):
             self.m.event_q.push('SYS_SERVER_RESCAN_DONE')
+
         def error(failure):
             self.m.event_q.push('SYS_SERVER_RESCAN_ERROR',
                                 error=str(failure.value))
@@ -587,7 +609,8 @@ class VolumeManager(object):
                 self._got_root(str(new_volume.node_id),
                                free_bytes=new_volume.free_bytes)
                 shares.append(volume_id)
-                # don't check the fsm node, the root fsm object is created in init_root
+                # don't check the fsm node,
+                # the root fsm object is created in init_root
             elif isinstance(new_volume, ShareVolume):
                 # check if the fsm node exists, and create it if not
                 self._create_fsm_object(volume.path, volume.id, volume.node_id)
@@ -627,6 +650,9 @@ class VolumeManager(object):
             # update the free_bytes on the volume
             self.update_free_space(volume_id, new_volume.free_bytes)
 
+        volumes = list(self.get_volumes(all_volumes=True))
+        events.append(("VM_VOLUMES_CHANGED", dict(volumes=volumes)))
+
         # push the collected events
         for event in events:
             self.m.event_q.push(event[0], **event[1])
@@ -921,7 +947,7 @@ class VolumeManager(object):
                        share_id, answer)
         share = self.shares[share_id]
         share.accepted = answer
-        self.shares[share_id] =  share
+        self.shares[share_id] = share
         answer_str = "Yes" if answer else "No"
         self.m.action_q.answer_share(share_id, answer_str)
 
@@ -964,8 +990,8 @@ class VolumeManager(object):
                 make_dir(share.path)
         # add the watch after the mkdir
         if share.can_write():
-             self.log.debug('adding inotify watch to: %s', share.path)
-             yield self._add_watch(share.path)
+            self.log.debug('adding inotify watch to: %s', share.path)
+            yield self._add_watch(share.path)
         # if it's a ro share, change the perms
         if not share.can_write():
             set_dir_readonly(share.path)
@@ -1169,19 +1195,35 @@ class VolumeManager(object):
                 return True
         return False
 
-    def create_udf(self, path):
-        """Request the creation of a UDF to AQ."""
-        self.log.debug('create udf: %r', path)
+    def validate_path_for_folder(self, path):
+        """Validate 'folder_path' for folder creation."""
+        path = normpath(path)
+        user_home = expand_user('~')
+        # handle folder_path not within '~'
+        if not path.startswith(user_home):
+            return (False, "UDFs must be within home")
+
         # check if path is the realpath, bail out if not
         if is_link(path):
-            self.m.event_q.push('VM_UDF_CREATE_ERROR', path=path,
-                                error="UDFs can not be a symlink")
-            return
+            return (False, "UDFs can not be a symlink")
+
+        # check if path exists but is not a directory
+        if path_exists(path) and not os.path.isdir(path):
+            return (False, "The path exists but is not a folder")
+
         # check if the path it's ok (outside root and
         # isn't a ancestor or child of another UDF)
         if self._is_nested_udf(path):
-            self.m.event_q.push('VM_UDF_CREATE_ERROR', path=path,
-                                error="UDFs can not be nested")
+            return (False, "UDFs can not be nested")
+
+        return (True, "")
+
+    def create_udf(self, path):
+        """Request the creation of a UDF to AQ."""
+        self.log.debug('create udf: %r', path)
+        valid, msg = self.validate_path_for_folder(path)
+        if not valid:
+            self.m.event_q.push('VM_UDF_CREATE_ERROR', path=path, error=msg)
             return
 
         try:
@@ -1212,7 +1254,7 @@ class VolumeManager(object):
     def delete_volume(self, volume_id):
         """Request the deletion of a volume to AQ.
 
-        if volume_id isn't in the shares or dufs shelf a KeyError is raised
+        if volume_id isn't in the shares or udfs shelf a KeyError is raised
 
         """
         self.log.info('delete_volume: %r', volume_id)
@@ -1454,7 +1496,7 @@ class MetadataUpgrader(object):
             make_dir(self._data_dir, recursive=True)
             self.update_metadata_version()
         elif path_exists(self._version_file):
-            with open(self._version_file) as fh:
+            with open_file(self._version_file) as fh:
                 md_version = fh.read().strip()
             if not md_version:
                 # we don't have a version of the metadata but a .version file?
@@ -1465,12 +1507,11 @@ class MetadataUpgrader(object):
         self.log.debug('metadata version: %s', md_version)
         return md_version
 
-
     def update_metadata_version(self):
         """Write the version of the metadata."""
         if not path_exists(os.path.dirname(self._version_file)):
             make_dir(os.path.dirname(self._version_file), recursive=True)
-        with open(self._version_file, 'w') as fd:
+        with open_file(self._version_file, 'w') as fd:
             fd.write(VolumeManager.METADATA_VERSION)
             # make sure the data get to disk
             fd.flush()
@@ -1486,7 +1527,8 @@ class MetadataUpgrader(object):
            and path_exists(self._shared_md_dir):
             # we have shares and shared dirs
             # md_version >= 1
-            old_root_dir = os.path.abspath(os.path.join(self._root_dir, 'My Files'))
+            old_root_dir = os.path.abspath(os.path.join(self._root_dir,
+                'My Files'))
             old_share_dir = os.path.abspath(os.path.join(self._root_dir,
                                                  'Shared With Me'))
             if path_exists(old_share_dir) and path_exists(old_root_dir) \
@@ -1506,7 +1548,8 @@ class MetadataUpgrader(object):
                 except OSError:
                     target = None
                 if is_link(self._shares_dir_link) \
-                   and normpath(target) == os.path.abspath(self._shares_dir_link):
+                and normpath(target) == os.path.abspath(
+                self._shares_dir_link):
                     # broken symlink, md_version = 4
                     md_version = '4'
                 else:
@@ -1515,7 +1558,7 @@ class MetadataUpgrader(object):
                     # check a pickled value to check if it's in version
                     # 5 or 6
                     md_version = '5'
-                    versions = {'5':0, '6':0}
+                    versions = {'5': 0, '6': 0}
                     for key in shelf:
                         share = shelf[key]
                         if isinstance(share, _Share):
@@ -1543,8 +1586,9 @@ class MetadataUpgrader(object):
         # pylint: disable-msg=W0612
         # filter 'shares' and 'shared' dirs, in case we are in the case of
         # missing version but existing .version file
-        filter_known_dirs = lambda d: d != os.path.basename(self._shares_md_dir)\
-                and d != os.path.basename(self._shared_md_dir)
+        filter_known_dirs = lambda d: d != os.path.basename(
+                self._shares_md_dir) and \
+                d != os.path.basename(self._shared_md_dir)
         for dirname, dirs, files in walk(self._data_dir):
             if dirname == self._data_dir:
                 for dir in filter(filter_known_dirs, dirs):
@@ -1586,7 +1630,6 @@ class MetadataUpgrader(object):
         .partial to .u1partial.
 
         """
-        from ubuntuone.platform.linux import allow_writes
         self.log.debug('upgrading from metadata 2 (bogus)')
         for top in self._root_dir, self._shares_dir:
             for dirpath, dirnames, filenames in walk(top):
@@ -1616,12 +1659,13 @@ class MetadataUpgrader(object):
                                   r'\1.u1conflict\2', name)
                 if new_name != name:
                     while os.path.lexists(os.path.join(dirpath, new_name)):
-                        m = re.match(r'(.*\.u1conflict)((?:\.\d+)?)$', new_name)
+                        m = re.match(r'(.*\.u1conflict)((?:\.\d+)?)$',
+                                     new_name)
                         base, num = m.groups()
                         if not num:
                             num = '.1'
                         else:
-                            num = '.' + str(int(num[1:])+1)
+                            num = '.' + str(int(num[1:]) + 1)
                         new_name = base + num
             if new_name != name:
                 old_path = os.path.join(dirpath, name)
@@ -1630,7 +1674,6 @@ class MetadataUpgrader(object):
                 rename(old_path, new_path)
                 names[pos] = new_name
 
-
     def _upgrade_metadata_3(self, md_version):
         """Upgrade to version 4 (new layout!)
 
@@ -1693,7 +1736,7 @@ class MetadataUpgrader(object):
                 old_path = path_join(old_root_dir, relpath)
                 new_path = path_join(self._root_dir, relpath)
                 if path_exists(new_path):
-                    recursive_move(new_path, new_path+'.u1conflict')
+                    recursive_move(new_path, new_path + '.u1conflict')
                 if relpath == 'Shared With Me':
                     # remove the Shared with Me symlink inside My Files!
                     self.log.debug('removing shares symlink from old root')
@@ -1721,7 +1764,8 @@ class MetadataUpgrader(object):
 
     def _upgrade_metadata_5(self, md_version):
         """Upgrade to version 6 (plain dict storage)."""
-        from ubuntuone.syncdaemon.volume_manager import VMFileShelf, LegacyShareFileShelf, UDF
+        from ubuntuone.syncdaemon.volume_manager import (
+            VMFileShelf, LegacyShareFileShelf, UDF)
         self.log.debug('upgrading from metadata 5')
         bkp_dir = os.path.join(os.path.dirname(self._data_dir), '5.bkp')
         new_md_dir = os.path.join(os.path.dirname(self._data_dir), 'md_6.new')
@@ -1757,7 +1801,9 @@ class MetadataUpgrader(object):
 
     def _upgrade_share_to_volume(self, share, shared=False):
         """Upgrade from _Share to new Volume hierarchy."""
-        from ubuntuone.syncdaemon.volume_manager import VMFileShelf, Root, Share, Shared
+        from ubuntuone.syncdaemon.volume_manager import (
+            VMFileShelf, Root, Share, Shared)
+
         def upgrade_share_dict(share):
             """Upgrade share __dict__ to be compatible with the
             new Share.__init__.
@@ -1794,7 +1840,7 @@ class MetadataUpgrader(object):
         """Upgrade to version 7, tritcask!."""
         from ubuntuone.syncdaemon.volume_manager import (
             VMFileShelf, VMTritcaskShelf,
-            SHARE_ROW_TYPE, SHARED_ROW_TYPE, UDF_ROW_TYPE
+            SHARE_ROW_TYPE, SHARED_ROW_TYPE, UDF_ROW_TYPE,
         )
         self.log.debug('upgrading from metadata 6')
         old_shares = VMFileShelf(self._shares_md_dir)
@@ -1874,10 +1920,10 @@ class LegacyShareFileShelf(VMFileShelf):
     """
 
     upgrade_map = {
-        ('ubuntuone.syncdaemon.volume_manager', 'UDF'):_UDF,
-        ('ubuntuone.syncdaemon.volume_manager', 'Share'):_Share,
+        ('ubuntuone.syncdaemon.volume_manager', 'UDF'): _UDF,
+        ('ubuntuone.syncdaemon.volume_manager', 'Share'): _Share,
         ('canonical.ubuntuone.storage.syncdaemon.volume_manager',
-         'Share'):_Share
+         'Share'): _Share,
     }
 
     def _find_global(self, module, name):
@@ -1891,7 +1937,7 @@ class LegacyShareFileShelf(VMFileShelf):
             return getattr(sys.modules[module], name)
 
     def _unpickle(self, fd):
-        """Override default _unpickle with one capable of migrating pickled classes."""
+        """Override _unpickle with one capable of migrating pickled classes."""
         unpickler = cPickle.Unpickler(fd)
         unpickler.find_global = self._find_global
         value = unpickler.load()
